Crate playerone_sdk

Crate playerone_sdk 

Structs

AllConfigBounds
Camera
CameraDescription
Description of a camera Can be used to open the camera and get access to many more functionality
CameraProperties
ConfigBounds
ROI
Region Of Interest
SensorMode
A sensor-mode slot reported by the camera. Player One cameras that advertise “Dual Sampling” typically expose at least "Normal" (higher FPS) and "LRN" (lower read noise). The set of modes is camera-specific and identified by the integer index used with crate::Camera::set_sensor_mode.

Enums

BayerPattern
ConfigKind
Error
ImageFormat