CameraProperties

Struct CameraProperties 

pub struct CameraProperties {
Show 19 fields pub camera_model_name: String, pub user_custom_id: String, pub camera_id: u32, pub max_width: u32, pub max_height: u32, pub bit_depth: u32, pub is_color_camera: bool, pub is_has_st_4_port: bool, pub is_has_cooler: bool, pub is_usb_3_speed: bool, pub bayer_pattern: BayerPattern, pub pixel_size: f64, pub serial_number: String, pub sensor_model_name: String, pub local_path: String, pub bins: Vec<u32>, pub img_formats: Vec<POAImgFormat>, pub is_support_hard_bin: bool, pub product_id: i32,
}

Fields

camera_model_name: String

the camera name

user_custom_id: String

user custom name, it will be added after the camera name, max len 16 bytes,like:Mars-C [Juno], default is empty

camera_id: u32max_width: u32

max width of the camera

max_height: u32

max height of the camera

bit_depth: u32

ADC depth of CMOS sensor

is_color_camera: bool

is a color camera or not

is_has_st_4_port: bool

does the camera have ST4 port, if not, camera don’t support ST4 guide

is_has_cooler: bool

does the camera have cooler assembly, generally, the cooled camera with cooler, window heater and fan

is_usb_3_speed: bool

is usb3.0 speed connection

bayer_pattern: BayerPattern

the bayer filter pattern of camera

pixel_size: f64

camera pixel size(unit: um)

serial_number: String

the serial number of camera, unique

sensor_model_name: String

the sensor model name, eg: IMX462

local_path: String

the path of the camera in the computer host

bins: Vec<u32>

bins supported by the camera, 1 == bin1, 2 == bin2,…

img_formats: Vec<POAImgFormat>

image data format supported by the camera

is_support_hard_bin: bool

does the camera sensor support hardware bin

product_id: i32

camera’s Product ID, note: the vID of PlayerOne is 0xA0A0