Structs
- AllConfig
Bounds - Camera
- Camera
Description - Description of a camera Can be used to open the camera and get access to many more functionality
- Camera
Properties - Config
Bounds - ROI
- Region Of Interest
- Sensor
Mode - A sensor-mode slot reported by the camera. Player One cameras that
advertise “Dual Sampling” typically expose at least
"Normal"(higher FPS) and"LRN"(lower read noise). The set of modes is camera-specific and identified by the integerindexused withcrate::Camera::set_sensor_mode.