pub enum ConfigKind {
Show 31 variants
Exposure,
Gain,
HardwareBin,
Temperature,
WbR,
WbG,
WbB,
Offset,
AutoexpoMaxGain,
AutoexpoMaxExposure,
AutoexpoBrightness,
GuideNorth,
GuideSouth,
GuideEast,
GuideWest,
Egain,
CoolerPower,
TargetTemp,
Cooler,
Heater,
HeaterPower,
FanPower,
FlipNone,
FlipHori,
FlipVert,
FlipBoth,
FrameLimit,
Hqi,
UsbBandwidthLimit,
PixelBinSum,
MonoBin,
}Variants
Exposure
exposure time(unit: us), read-write
Gain
gain, read-write
HardwareBin
hardware bin, read-write
Temperature
camera temperature(uint: C), read-only
WbR
red pixels coefficient of white balance, read-write
WbG
green pixels coefficient of white balance, read-write
WbB
blue pixels coefficient of white balance, read-write
Offset
camera offset, read-write
AutoexpoMaxGain
maximum gain when auto-adjust, read-write
AutoexpoMaxExposure
maximum exposure when auto-adjust(uint: ms), read-write
AutoexpoBrightness
target brightness when auto-adjust, read-write
GuideNorth
ST4 guide north, generally,it’s DEC+ on the mount, read-write
GuideSouth
ST4 guide south, generally,it’s DEC- on the mount, read-write
GuideEast
ST4 guide east, generally,it’s RA+ on the mount, read-write
GuideWest
ST4 guide west, generally,it’s RA- on the mount, read-write
Egain
e/ADU, This value will change with gain, read-only
CoolerPower
cooler power percentage[0-100%](only cool camera), read-only
TargetTemp
camera target temperature(uint: C), read-write
Cooler
turn cooler(and fan) on or off, read-write
Heater
(deprecated)get state of lens heater(on or off), read-only
HeaterPower
lens heater power percentage[0-100%], read-write
FanPower
radiator fan power percentage[0-100%], read-write
FlipNone
no flip, Note: set this config(POASetConfig), the ‘confValue’ will be ignored, read-write
FlipHori
flip the image horizontally, Note: set this config(POASetConfig), the ‘confValue’ will be ignored, read-write
FlipVert
flip the image vertically, Note: set this config(POASetConfig), the ‘confValue’ will be ignored, read-write
FlipBoth
flip the image horizontally and vertically, Note: set this config(POASetConfig), the ‘confValue’ will be ignored, read-write
FrameLimit
Frame rate limit, the range:[0, 2000], 0 means no limit, read-write
Hqi
High Quality Image, for those without DDR camera(guide camera), if set POA_TRUE, this will reduce the waviness and stripe of the image,\n< but frame rate may go down, note: this config has no effect on those cameras that with DDR. read-write
UsbBandwidthLimit
USB bandwidth limit, read-write
PixelBinSum
take the sum of pixels after binning, POA_TRUE is sum and POA_FLASE is average, default is POA_FLASE, read-write
MonoBin
only for color camera, when set to POA_TRUE, pixel binning will use neighbour pixels and image after binning will lose the bayer pattern, read-write